from src.config import Config

from fastapi import APIRouter, Request
from fastapi.responses import HTMLResponse, JSONResponse
from fastapi.templating import Jinja2Templates

from src.core.manager import TaskManager

collection_router = APIRouter(prefix='/collection', tags=['Identification'])
conf = Config()
templates = Jinja2Templates(directory="templates")
task_manager = TaskManager()


@collection_router.get("/", response_class=HTMLResponse)
async def get_collection(request: Request):
    ctx = {'methods': conf.get_methods(only_names=True)}
    return templates.TemplateResponse(request=request, name="collection.html", context=ctx)


@collection_router.get('/collection/{command}/{n}', response_class=JSONResponse)
async def get_collection_data(command: str, n: int):
    response = task_manager.get_saved_data(command, n, conf.data_base)
    return response


# Specific collection
@collection_router.get('/collection/{command}', response_class=HTMLResponse)
async def get_specific_collection_data(command: str, request: Request):
    ctx = {'command_name': command}
    return templates.TemplateResponse(
        request=request, name='specific_collection.html', context=ctx
    )
