from datetime import datetime

import av
from aiortc import MediaStreamTrack

from src.config import Config
from src.core.manager import TaskManager

task_manager = TaskManager()
conf = Config()


class RecognitionTrack(MediaStreamTrack):
    """
    A video stream track that transforms frames from an another track.
    """

    kind = 'video'

    def __init__(self, track, data_channel, task: str):
        super().__init__()  # don't forget this!

        self.task = task
        self.track = track
        self.channel = data_channel

        self._frame_number = 0
        # self._frames = []

        self._last_predictions: dict[str, dict[str, str | float]] | None = None  # todo
        self._last_execution: datetime | None = None

    def finish(self):
        pass
        # if self.frames:
        #     out = cv2.VideoWriter(f'media/{self.user.id}_project.avi',
        #                           cv2.VideoWriter_fourcc(*'DIVX'), 30, self.frames[0].shape)
        #
        #     for frame in self.frames:
        #         out.write(frame)
        #     out.release()

    async def recv(self):
        self._frame_number += 1
        frame = await self.track.recv()

        time = datetime.now()
        commands = [self.task]

        img = frame.to_ndarray(format='rgb24')
        if self._last_execution is None or (time - self._last_execution).microseconds / 1e6 > conf.IDENTIFICATION_MIN_INTERVAL:
            t1 = datetime.now()
            img, predictions = task_manager.execute_commands({'byte_data': img, 'commands': commands},
                                                             models=conf.models['Identification'],
                                                             data_base=conf.data_base
                                                             )
            self._last_predictions = predictions
            self._last_execution = datetime.now()
        elif self._last_predictions is not None:
            img = task_manager.draw_predictions(commands,
                                                models=conf.models['Identification'],
                                                frame=img,
                                                predictions=self._last_predictions)
        else:
            return frame
        #
        # # to do some

        new_frame = av.VideoFrame.from_ndarray(img, format='rgb24')
        new_frame.pts = frame.pts
        new_frame.time_base = frame.time_base

        return new_frame
