import os
from pathlib import Path
import dotenv

from src.db.system_storage import SystemDB
from src.models.identification_fr import IdentificationFaceRecognitionModel
from src.models.detection_fr import DetectionFaceRecognitionModel


dotenv.load_dotenv(Path(__file__).parent.parent / ".env")
# Names of methods and models must not contain the "_" character
# For identification models, the first key of predictions must have the name "name"


class Config:
    def __init__(self):
        self.data_base = SystemDB(os.getenv("DATA_DIR"))
        self.IDENTIFICATION_MIN_INTERVAL: float = float(os.getenv("IDENTIFICATION_MIN_INTERVAL"))  # seconds

        self.models = {
            "Identification": {
                "FaceRecognition": IdentificationFaceRecognitionModel(),
            },
            "Detection": {
                "FaceRecognition": DetectionFaceRecognitionModel(),
                "OpenCV": DetectionFaceRecognitionModel()
            }
        }

    def get_methods(self, only_names=False, methods_names: list[str] = None) -> dict:
        methods = dict()
        methods_names = methods_names if methods_names else list(self.models.keys())
        for method_name, method_models in self.models.items():
            if method_name in methods_names:
                if only_names:
                    methods[method_name] = list(method_models.keys())
                else:
                    for model_name, method_model_class in method_models.items():
                        methods[f"{method_name}_{model_name}"] = method_model_class

        return methods
