from pathlib import Path
import json

from src.db.main import InterfaceDB


class SystemDB(InterfaceDB):
    def __init__(self, data_path: str):
        """Configure the data folder"""
        self.data_path = Path(data_path)

    def get(self, table: str, fields: list[str] = None) -> dict:
        """
        Get data from file system
        :param table: paths to the data JSON file
        :param fields: keys in the JSON file
        :return: dict with data
        """
        response = dict()
        try:
            with open(self.data_path / "images/data.json", "r") as f:
                if f.read():
                    f.seek(0)
                    file_data = json.load(f)
                    tss = [image_name.split("_")[-1] for image_name in file_data]

            if "preview" in table:
                table_path = "images/data.json"
            elif "anns" in table:
                table_path = table.split("_anns")[0] + "/anns.json"
            else:
                table_path = table + "/data.json"

            with open(self.data_path / table_path, 'r') as f:
                if f.read():
                    f.seek(0)
                    file_data = json.load(f)
                    for key, values in file_data.items():
                        if key.split("_")[-1] in tss:
                            response[key] = dict()
                            if fields:
                                response[key].update({field: values[field] for field in fields})
                            else:
                                response[key].update(values)
                        else:
                            self.delete(table, key)
                            print(f"Update {self.data_path / table_path}: delete {key}")

        except Exception as error:
            print("An exception occurred (db/system_storage):", error)

        return response

    def add(self, table: str, fields: dict) -> bool:
        """
        Add data to local storage
        :param table: path to file with data
        :param fields: data which we want to save
        :return: status of saving
        """
        response = False
        try:
            if "preview" in table:
                table_path = "images/data.json"
            elif "anns" in table:
                table_path = table.split("_anns")[0] + "/anns.json"
            else:
                table_path = table + "/data.json"

            file_path = self.data_path / table_path
            if not file_path.exists():
                file_path.parent.mkdir(parents=True, exist_ok=True)
                file_path.touch()

            file_data = dict()
            with open(file_path, 'r') as f:
                if f.read():
                    f.seek(0)
                    file_data = json.load(f)

            with open(file_path, 'w') as f:
                file_data.update(fields)
                json.dump(file_data, f, indent=4)

            response = True
        except Exception as error:
            print("An exception occurred (db/system_storage):", error)

        return response

    def edit(self):
        pass

    def delete(self, table: str, fields: str) -> bool:
        response = False
        try:
            if "preview" in table:
                table_path = "images/data.json"
            elif "anns" in table:
                table_path = table.split("_anns")[0] + "/anns.json"
            else:
                table_path = table + "/data.json"

            file_path = self.data_path / table_path
            if file_path.exists():
                file_data = dict()
                with open(file_path, 'r') as f:
                    if f.read():
                        f.seek(0)
                        file_data = json.load(f)

                        if fields in file_data:
                            del file_data[fields]
                        else:
                            raise Exception(f"There is no {fields} value in the {file_path} file")

                with open(file_path, 'w') as f:
                    json.dump(file_data, f, indent=4)
                    response = True

        except Exception as error:
            print("An exception occurred (db/system_storage):", error)

        return response
