import numpy as np
import cv2
import face_recognition

from src.models.main import InterfaceModel


class DetectionFaceRecognitionModel(InterfaceModel):
    def predict(self, decoded_data: np.array, params: dict) -> dict:
        results = dict(
            bbox=[]
        )
        try:
            results["bbox"] += face_recognition.face_locations(decoded_data)
        except Exception as error:
            print("An exception occurred (models/detection_facerecognition):", error)

        return results

    def apply_predictions(self, image: np.array, predictions: dict) -> np.array:
        """Apply predictions to the data stream"""
        for y_top, x_right, y_bottom, x_left in predictions["bbox"]:
            cv2.rectangle(image, (x_left, y_top), (x_right, y_bottom), (255, 0, 0), 2)

        return image
