const video = document.getElementById('video')

const hidden_canvas = window.canvas = document.getElementById('hidden_canvas')
const hidden_context = canvas.getContext("2d")

const visible_canvas = window.canvas = document.getElementById('visible_canvas')
const visible_context = canvas.getContext("2d")


function startStream() {
    navigator.mediaDevices.getUserMedia({video: {}})
        .then((stream) => {
            // Use the stream
            video.srcObject = stream
            let canvasVideo = setInterval(function () { streamCanvas() }, 1500)
        })
        .catch((err) => {
            // Handle the error
            console.error(err)
        });
}


async function streamCanvas() {
    hidden_canvas.width = video.videoWidth
    hidden_canvas.height = video.videoHeight
    hidden_context.drawImage(video, 0, 0, canvas.width, canvas.height)

    const data = getFrontendData()
    if (data["commands"].length) {
        // Get predictions
        const predictions = await predict(data)
        // Paste data
        const image = new Image()
        image.src = predictions["byte_image"]
        image.onload = function() {
            visible_canvas.width = video.videoWidth
            visible_canvas.height = video.videoHeight
            visible_context.drawImage(image, 0, 0, visible_canvas.width, visible_canvas.height)
        }
        await pasteData(predictions["predictions"])
    } else {
        visible_canvas.width = video.videoWidth
        visible_canvas.height = video.videoHeight
        visible_context.drawImage(video, 0, 0, visible_canvas.width, visible_canvas.height)
    }
}


async function predict(data){
    // Send POST request to backend
    let response = null
    try {
        const predict = await fetch("/predict", {
            method: "POST",
            headers: {
                "Content-Type": "application/json"
            },
            body: JSON.stringify(data)
        })
        response = await predict.json()
    } catch (err) {
        // Handle the error
        console.error("An exception occurred (record/predict)", err.message)
    }

    return response
}


function getFrontendData() {
    let coms = []
    const b_image = hidden_canvas.toDataURL()
    const params = {}

    const inputElements = document.getElementsByName('left_radio')
    for (const inputElement of inputElements) {
        if (inputElement.checked) {
            const model = inputElement.id.split("_").slice(-1)[0]
            if (model !== "disable") {
                coms.push("Identification_" + model)
            }
        }
    }

    return {commands: coms, byte_data: b_image, params: params}
}


function radioListener(radioId) {
    const selectedModel = radioId.split("left_radio_").slice(-1)[0]
    const leftRadios = document.getElementsByName("left_radio")
    for (const leftRadio of leftRadios) {
        const model = leftRadio.id.split("left_radio_").slice(-1)[0]
        if (model === "disable") {
            continue
        }
        const accordionRightItem = document.getElementById(`accordion_right_item_${model}`)
        accordionRightItem.classList.add("d-none")
        if (model === selectedModel) {
            accordionRightItem.classList.remove("d-none")
        }
    }
}


function pasteData(data) {
    for (const methodModel in data) {
        const accordionRightContent = document.getElementById(`accordion_right_content_${methodModel.split("_").slice(-1)[0]}`)
        accordionRightContent.textContent = JSON.stringify(data[methodModel])
    }
}


startStream()
