const video = document.getElementById('video');
const hidden_canvas = window.canvas = document.getElementById('hidden_canvas')
const hidden_context = canvas.getContext("2d")

const visible_canvas = window.canvas = document.getElementById('visible_canvas')
const visible_context = canvas.getContext("2d")


function startFixingFaceState() {
    document.getElementById('btn-start-capture').classList.add('d-none');
    video.classList.remove('d-none')
}


function createConnection() {
    // Создаем WebRTC соединение между браузером и сервером
    var config = {
        sdpSemantics: 'unified-plan',
        frameRate: {
            max: 10
        }
    };

    let pc = new RTCPeerConnection(config);
    let iceGatheringLog = '', iceConnectionLog = '', signalingLog = '';

    pc.addEventListener('icegatheringstatechange', function() {
        console.log('icegatheringstatechange', pc.iceGatheringState)
        iceGatheringLog += ' -> ' + pc.iceGatheringState;
    }, false);
    iceGatheringLog = pc.iceGatheringState;

    pc.addEventListener('iceconnectionstatechange', function() {
        console.log('iceconnectionstatechange', pc.iceConnectionState)
        iceConnectionLog += ' -> ' + pc.iceConnectionState;
    }, false);
    iceConnectionLog = pc.iceConnectionState;

    pc.addEventListener('signalingstatechange', function() {
        console.log('signalingstatechange', pc.signalingState)
        signalingLog += ' -> ' + pc.signalingState;
    }, false);

    signalingLog = pc.signalingState;

    pc.addEventListener('track', function(evt) {
        console.log('track', evt);
        video.srcObject = evt.streams[0];
    });

    return pc;
}


function startStream(e) {

    pc = createConnection();  // RTCPeerConnection
    console.log('created')
    pc.ondatachannel = function (event) {
        console.log('new channel')

        var channel = event.channel;
        channel.onopen = function(event) {
            channel.send('Hi back!');
        }
        channel.onmessage = function(event) {
            console.log(event.data);
        }
    }

    navigator.mediaDevices.getUserMedia({video: {}})
        .then((stream) => {
            // Use the stream
            stream.getTracks().forEach(function(track) {
                console.log('add track')
                pc.addTrack(track, stream);
            });

            startFixingFaceState();
            return negotiate();
        })
        .catch((err) => {
            // Handle the error
            console.error(err)
        });
}

function negotiate() {
    console.log('negotiate')
    return pc.createOffer().then(function(offer) {
        return pc.setLocalDescription(offer);
    }).then(function() {
        // wait for ICE gathering to complete
        return new Promise(function(resolve) {
            if (pc.iceGatheringState === 'complete') {
                resolve();
            } else {
                function checkState() {
                    console.log('checkState')
                    if (pc.iceGatheringState === 'complete') {
                        pc.removeEventListener('icegatheringstatechange', checkState);
                        resolve();
                    }
                }
                pc.addEventListener('icegatheringstatechange', checkState);
            }
        });
    }).then(function() {
        var offer = pc.localDescription;

//        offer.sdp = sdpFilterCodec('video', 'H264/90000', offer.sdp);  // VP8/90000

        return fetch('/identification/watch/', {
            body: JSON.stringify({
                sdp: offer.sdp,
                type: offer.type,
                task: document.querySelector('input[name="task-option"]:checked').value,
                options: {
                    size: 100//document.getElementBySelector('input[name="size"]').value
                }
            }),
            headers: {
                'Content-Type': 'application/json'
            },
            method: 'POST'
        });
    }).then(function(response) {
        if (response.status === 400) {
            throw 'Server error: ' + response.statusText;
        }
        return response.json();
    }).then(function(answer) {
        console.log(answer);
        return pc.setRemoteDescription(answer);
    }).catch(function(e) {
        alert(e);
    });
}

function showPredictions(data) {
    const divElements = document.getElementsByClassName('accordion-item')
    for (const divElement of divElements) {
        const model = divElement.id.split("_").slice(-1)[0]
        const inputElement = document.getElementById("left_radio_" + model)
        if (inputElement.checked) {
            if (divElement.classList.contains("d-none")) {
                divElement.classList.remove("d-none")
            }
            const pElement = document.getElementById("accordion_right_content_" + model)
            const value = data['predictions']["Identification_" + model]
            pElement.textContent = JSON.stringify(value)
        } else {
            if (!divElement.classList.contains("d-none")) {
                divElement.classList.add("d-none")
            }
        }
    }
}


function stopStream(e) {
}


document.getElementById('btn-start-capture').onclick = startStream;
document.getElementById('btn-stop-capture').onclick = stopStream;

