const video = document.getElementById('video')

const hidden_canvas = window.canvas = document.getElementById('hidden_canvas')
const hidden_context = canvas.getContext("2d")

const visible_canvas = window.canvas = document.getElementById('visible_canvas')
const visible_context = canvas.getContext("2d")


// Stream webcam
function startStream() {
    navigator.mediaDevices.getUserMedia({video: {}})
        .then((stream) => {
            // Use the stream
            video.srcObject = stream
            let canvasVideo = setInterval(function () { streamCanvas() }, 1500)
        })
        .catch((err) => {
            // Handle the error
            console.error(err)
        });
}


async function streamCanvas() {
    hidden_canvas.width = video.videoWidth
    hidden_canvas.height = video.videoHeight
    hidden_context.drawImage(video, 0, 0, canvas.width, canvas.height)

    // Check checkboxes
    const data = getFrontendData()
    if (data["commands"].length) {
        // Get predictions
        const predictions = await predict(data)
        // Paste data
        const image = new Image()
        image.src = predictions["byte_image"]
        image.onload = function() {
            visible_canvas.width = video.videoWidth
            visible_canvas.height = video.videoHeight
            visible_context.drawImage(image, 0, 0, visible_canvas.width, visible_canvas.height)
        }
        await pasteData(predictions["predictions"])
    } else {
        visible_canvas.width = video.videoWidth
        visible_canvas.height = video.videoHeight
        visible_context.drawImage(video, 0, 0, visible_canvas.width, visible_canvas.height)
    }
}


// Get method_model that are enabled
function getFrontendData() {
    let methodModels = []
    const byteImage = hidden_canvas.toDataURL()
    const params = {}

    const checkboxes = document.getElementsByName('methods_checkboxes')
    for (const checkbox of checkboxes) {
        if (checkbox.checked) {
            const innerCheckboxes = document.getElementsByName(checkbox.id.split("checkbox_").slice(-1)[0])
            for (const innerCheckbox of innerCheckboxes) {
                if (innerCheckbox.checked) {
                    methodModels.push(innerCheckbox.id.split("inner_checkbox_").slice(-1)[0])
                }
            }
        }
    }

    return {commands: methodModels, byte_data: byteImage, params: params}
}


// Get predictions
async function predict(data){
    // Send POST request to backend
    let response = null
    try {
        const predictions = await fetch("/predict", {
            method: "POST",
            headers: {
                "Content-Type": "application/json"
            },
            body: JSON.stringify(data)
        })
        response = await predictions.json()
    } catch (err) {
        // Handle the error
        console.error("An exception occurred (record/predict)", err.message)
    }

    return response
}


// Listeners on the checkboxes
function checkboxListener(method) {
    const accordionDesMethodItem = document.getElementById(`accordion_des_method_item_${method}`)
    if (document.getElementById(`checkbox_${method}`).checked) {
        const innerCheckboxes = document.getElementsByName(method)
        const areInnerCheckboxesOn = [...innerCheckboxes].map(innerCheckbox => innerCheckbox.checked)
        if (areInnerCheckboxesOn.includes(true)) {
            innerCheckboxes.forEach(innerCheckbox => {
                if (innerCheckbox.checked) {
                    const method_model = innerCheckbox.id.split("inner_checkbox_").slice(-1)[0]
                    const accordionDesMethodModelItem = document.getElementById(`accordion_des_method_model_item_${method_model}`)
                    accordionDesMethodModelItem.classList.remove("d-none")
                }
            })
            accordionDesMethodItem.classList.remove("d-none")
        }
    } else {
        accordionDesMethodItem.classList.add("d-none")
    }
}


function innerCheckboxListener(method_model) {
    const accordionDesMethodModelItem = document.getElementById(`accordion_des_method_model_item_${method_model}`)
    const method = method_model.split("_")[0]
    const accordionDesMethodItem = document.getElementById(`accordion_des_method_item_${method}`)
    if (document.getElementById(`inner_checkbox_${method_model}`).checked) {
        const isParentCheckboxOn = document.getElementById(`checkbox_${method}`).checked
        if (isParentCheckboxOn) {
            accordionDesMethodItem.classList.remove("d-none")
            accordionDesMethodModelItem.classList.remove("d-none")
        }
    } else {
        accordionDesMethodModelItem.classList.add("d-none")
        const innerCheckboxes = document.getElementsByName(method)
        const areInnerCheckboxesOn = [...innerCheckboxes].map(innerCheckbox => innerCheckbox.checked)
        if (!areInnerCheckboxesOn.includes(true)) {
            accordionDesMethodItem.classList.add("d-none")
        }
    }
}


// Function for inserting data
function pasteData(data) {
    for (const methodModel in data) {
        const element = document.getElementById(`accordion_des_method_model_content_${methodModel}`)
        element.textContent = JSON.stringify(data[methodModel])
    }
}


startStream()
