async function loadImages(){
    const h2Elements = document.querySelectorAll("h2")
    const methodModel = h2Elements[0].id.split("title_").slice(-1)[0]
    const divElementsIds = [...h2Elements].map(h2Element => h2Element.id.includes("anns") ? `anns_image_grid_${methodModel}` : `image_grid_${methodModel}`)

    for (const divElementId of divElementsIds) {
        const divElement = document.getElementById(divElementId)
        const divMethodModel = divElementId.includes("anns") ? `${methodModel}_anns` : methodModel
        let response = {}
        try {
            const imagesData = await fetch(`/collection/${divMethodModel}/-1`, {
                method: "GET",
                headers: {
                    "Content-Type": "application/json"
                }
            })
            response = await imagesData.json()
        } catch (err) {
            // Handle the error
            console.error(err)
        }

        if (Object.keys(response).length) {
            for (const imageName in response) {
                const imageId = `${divMethodModel}_${imageName.split(".")[0]}`
                divElement.innerHTML +=
                    `
                    <div class="col mb-4">
                        <button type="button" class="btn btn-link" data-bs-toggle="modal" data-bs-target="#modal_${imageId}">
                            <img class="rounded" src="${response[imageName]['byte_image']}" alt="${imageName}">
                        </button>
                    </div>
                    <div class="modal fade" id="modal_${imageId}" data-bs-backdrop="static" data-bs-keyboard="false" tabindex="-1" aria-labelledby="modal_header_${imageId}" aria-hidden="true">
                        <div class="modal-dialog modal-dialog-centered modal-dialog-scrollable modal-xl">
                            <div class="modal-content">
                                <div class="modal-header">
                                    <h5 class="modal-title" id="modal_header_${imageId}">${divMethodModel}</h5>
                                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                                </div>
                                <div class="modal-body">
                                    <p>${JSON.stringify(response[imageName])}</p>
                                </div>
                                <div class="modal-footer">
                                    <button type="button" class="btn btn-danger" onclick="deleteData('${divMethodModel}', '${imageName}')">Delete</button>
                                    <button type="button" class="btn btn-primary" data-bs-dismiss="modal">Close</button>
                                </div>
                            </div>
                        </div>
                    </div>
                    `
            }
        }
    }
}


async function deleteData(command, imageName) {
    let response = {}
    try {
        const status = await fetch(`/delete`, {
            method: "POST",
            headers: {
                "Content-Type": "application/json"
            },
            body: JSON.stringify({commands: [command], params: {image_id: imageName}})
        })
        response = await status.json()
    } catch (err) {
        // Handle the error
        console.error(err)
    }
    // Display status
    alert(JSON.stringify(response))
}


loadImages()
