import io
import base64
from PIL import Image
import numpy as np


def decode_image(b_image: str | np.ndarray) -> np.ndarray:
    """
    Decode bytes to image.

    Args:
        b_image: bytes (base64).

    Return:
         Numpy array image.
    """
    if isinstance(b_image, str):
        img = b_image.split("data:image/png;base64,")[-1]
        img = io.BytesIO(base64.b64decode(img))
        img = Image.open(img).convert("RGB")

        return np.array(img)

    return b_image


def encode_image(image: np.ndarray) -> str:
    image_out = Image.fromarray(image)
    buffer = io.BytesIO()
    image_out.save(buffer, format="PNG")
    return "data:image/png;base64," + base64.b64encode(buffer.getvalue()).decode("utf-8")
